﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Reflection;
using System.Threading.Tasks;
using System.Linq;
using System.Windows;
using Stimulsoft.Report;
using System.Threading;
using System.Globalization;

namespace StimulsoftSampleProject
{
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private async void Button_Click(object sender, RoutedEventArgs e)
        {
            await RenderReport("StimulsoftSampleProject.Report.mrt");
        }

        private async Task RenderReport(string reportName)
        {

            var cultureInfo = new CultureInfo("de-AT");
            Thread.CurrentThread.CurrentCulture = cultureInfo;
            CultureInfo.DefaultThreadCurrentCulture = cultureInfo;

            var UIcultureInfo = new CultureInfo("en");
            Thread.CurrentThread.CurrentUICulture = UIcultureInfo;
            CultureInfo.DefaultThreadCurrentUICulture = UIcultureInfo;
            var report = new StiReport();

            var assembly = Assembly.GetExecutingAssembly();
            var reportResourceName = reportName;

            StiOptions.Dictionary.RemoveUnusedDataBeforeReportRendering = true;


            using (Stream stream = assembly.GetManifestResourceStream(reportResourceName))
            {
                

                using (StreamReader reader = new StreamReader(stream))
                {
                    var data = new byte[stream.Length];
                    stream.Read(data, 0, data.Length);

                    report.Load(data);
                    report.RegBusinessObject("DailyLogs", GetTestDataChartSample());

                    report.Dictionary.SynchronizeBusinessObjects(2);

                    
                    report.ReportCacheMode = StiReportCacheMode.Off;
                    report.CacheAllData = false;
                    report.AutoLocalizeReportOnRun = true;

                             
                    //report.DesignV2WithWpf();                   
                    await report.RenderAsync();


                    //if I display the report now, everything works
                    //report.ShowWithWpf();  

                    //BUT - if i packit and unpack it, it doesnt work
                    var result = report.SavePackedDocumentToByteArray();

                    //does not work
                    StiReport report2 = new StiReport();
                    report2.LoadPackedDocument(result);
                    
                    //now the dates are not recognized as dates
                    report2.ShowWithWpf();
                }
            }
        }

        private List<DailyLog> GetTestDataChartSample()
        {
            var list = new List<DailyLog>();
            DateTime tmp = new DateTime(2020, 01, 01);
            var rand = new Random();
            var task = "Pipe";



            var installationItemAverage = new DailyLog
            {
                Day = System.DateTime.Now,                
                PlannedStart = new DateTime(2018,03,01),
                PlannedEnd = new DateTime(2018, 03, 30),
                Task = "Test",
                Names = new List<Name>()
            };
            list.Add(installationItemAverage);




            return list;
        }

        private List<DailyLog> GetTestData()
        {
            var list = new List<DailyLog>();
            DateTime tmp = new DateTime(2020, 01, 01);
            var rand = new Random();
            var task = "Pipe";

            

           
            tmp = new DateTime(2020, 01, 01);

            for (int item = 0; item < 2; item++)
            {
                //52 Wochen
                for (int i = 1; i <= 52; i++)
                {

                    //einen Tag erhöhen

                    tmp = tmp.AddDays(1);
                    var plannedProgressIncrease = (100 / 52);

                    var installationItemAverage = new DailyLog
                    {
                        Day = tmp,
                        PlannedValue = ((decimal)(i * plannedProgressIncrease)),
                        Value = ((decimal)(i * plannedProgressIncrease)) + rand.Next(-10, 10),
                        Names = new List<Name>()
                    };
                    list.Add(installationItemAverage);
                }
            }
             


            return list;
        }
    }
}